import { Typography } from '@mui/material';
import React from 'react';
import { Document, makeThumbnailUrl } from '../../accessor/document';
import {ComicReader} from './comic';
import {VideoReader} from './video'

export interface PagePresenterProp{
    doc:Document,
    className?:string
}
interface PagePresenter{
    (prop:PagePresenterProp):JSX.Element
}

export const getPresenter = (content:Document):PagePresenter => {
    switch (content.content_type) {
        case "comic":
            return ComicReader;
        case "video":
            return VideoReader;
    }
    return ()=><Typography variant='h2'>Not implemented reader</Typography>;
}

export const ThumbnailContainer = (props:{content:Document, className?:string, style?:React.CSSProperties})=>{
    const thumbnailurl = makeThumbnailUrl(props.content);
    if(props.content.content_type === "video"){
        return (<video src={thumbnailurl} muted autoPlay loop className={props.className} style={props.style}></video>)
    }
    else return (<img src={thumbnailurl} className={props.className} style={props.style}></img>)
}